@@ -13,8 +13,6 @@ import requests
 import logging
 import six
 import sentry
-from datetime import datetime
-from pytz import timezone
 
 from django import forms
 from django.conf import settings
@@ -28,6 +26,8 @@ from sentry.utils.safe import safe_execute
 from sentry.utils.http import absolute_uri
 from django.core.urlresolvers import reverse
 
+WECHAT_WEBHOOK_URL = "https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key={key}"
+
 
 def validate_urls(value, **kwargs):
     output = []
@@ -113,21 +113,17 @@ class WechatPlugin(notify.NotificationPlugin):
         return absolute_uri(group.get_absolute_url())
 
     def notify_users(self, group, event, *args, **kwargs):
-        url = self.get_webhook_urls(group.project)
-        project = event.project
-        host = self.get_option("host", project) or ''
-        safe = self.get_option("safe", project)
+        key = self.get_option('key', group.project)
+        url = WECHAT_WEBHOOK_URL.format(key=key)
+        title = u"有新的通知来自 {} 项目".format(event.project.slug)
         data = {
-            "msgtype": "text",
-            'safe': '1' if safe else '0',
-            "text": {
-                    "content": '[标题] {}\n[时间] {}\n[{}] {}\n[href]({})'.format(
-                        "Sentry {} 项目告警".format(project.slug),
-                        datetime.now(timezone('Asia/Shanghai')).strftime("%Y-%m-%d %H:%M:%S"),
-                        event.get_tag('level').capitalize(),
-                        event.message.encode('utf8'),
-                        "{}{}events".format(host,group.get_absolute_url())
-                    )
+            "msgtype": "markdown",
+            "markdown": {
+                "content": u"#### {title} \n > {message} [查看]({url})".format(
+                    title=title,
+                    message=event.message,
+                    url=u"{}events/{}/".format(group.get_absolute_url(), event.id),
+                )
             }
         }
         headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}
